/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: AndroidTaxonomyPreferences.java,v 1b1c65ce3709 2010/07/24 21:14:43 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.android.taxonomy;

import javax.annotation.Nonnull;
import org.openide.util.Lookup;
import org.openide.util.lookup.ServiceProvider;
import it.tidalwave.util.logging.Logger;
import it.tidalwave.bluebill.taxonomy.Taxon;
import it.tidalwave.bluebill.taxonomy.Taxonomy;
import it.tidalwave.bluebill.mobile.taxonomy.TaxonomyPreferences;
import it.tidalwave.bluebill.mobile.taxonomy.TaxonomyPreferencesSupport;
import android.text.Html;
import android.content.SharedPreferences;
import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
import android.content.res.AssetManager;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: $
 *
 **********************************************************************************************************************/
@ServiceProvider(service=TaxonomyPreferences.class)
public class AndroidTaxonomyPreferences extends TaxonomyPreferencesSupport
  {
    private static final String CLASS = AndroidTaxonomyPreferences.class.getName();
    private static final Logger logger = Logger.getLogger(CLASS);

    @Nonnull
    private final AssetManager assets = Lookup.getDefault().lookup(AssetManager.class);

    @Nonnull
    private final SharedPreferences preferences = Lookup.getDefault().lookup(SharedPreferences.class);

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    private final OnSharedPreferenceChangeListener listener = new OnSharedPreferenceChangeListener()
      {
        public void onSharedPreferenceChanged (final @Nonnull SharedPreferences sharedPreferences,
                                               final @Nonnull String string)
          {
            logger.info("onSharedPreferenceChanged(%s, %s)", sharedPreferences, string);
            reset();
          }
      };

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public AndroidTaxonomyPreferences()
      {
        preferences.registerOnSharedPreferenceChangeListener(listener);
        reset();
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    @Override @Nonnull
    protected Taxonomy loadTaxonomy()
      throws Exception
      {
        return loadTaxonomy(assets.open(getSelectedTaxononyName() + ".json"), "UTF-8");
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    @Override @Nonnull
    public CharSequence formatAsHtml (final @Nonnull Taxon taxon, final @Nonnull String extra)
      {
        return Html.fromHtml(super.formatAsHtml(taxon, extra).toString());
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    @Override @Nonnull
    public CharSequence formatAsHtmlSingleLanguageAndScientific (final @Nonnull Taxon taxon, final @Nonnull String extra)
      {
        return Html.fromHtml(super.formatAsHtmlSingleLanguageAndScientific(taxon, extra).toString());
      }
  }
